@@ -21,6 +21,9 @@ class PartitionBaseTable(NetBoxTable):
     size = tables.Column(
         linkify=True
     )
+    type = tables.Column(
+        linkify=True
+    )
 
 
 class PartitionTable(PartitionBaseTable):
@@ -38,9 +41,9 @@ class PartitionTable(PartitionBaseTable):
             "description",
         )
         default_columns = (
-            "drive",
             "device",
             "size",
+            "type"
         )
 
 
